pub struct Quaternion {
pub x: f32,
pub y: f32,
pub z: f32,
pub w: f32,
}Expand description
Unit quaternion used for 3D rotation interpolation.
The components are stored as (x, y, z, w). Interpolate uses
shortest-path spherical linear interpolation.
Fields
x: f32X component of the vector part.
y: f32Y component of the vector part.
z: f32Z component of the vector part.
w: f32Scalar part.
Implementations
Sourceimpl Quaternion
impl Quaternion
Sourcepub fn from_axis_angle(axis: [f32; 3], angle: Angle) -> Self
pub fn from_axis_angle(axis: [f32; 3], angle: Angle) -> Self
Create a quaternion from an axis and angle in degrees.
Sourcepub fn normalized(self) -> Self
pub fn normalized(self) -> Self
Return a normalized quaternion, or identity when length is invalid.